otcextensions.sdk.vlb.v3.quota
==============================

.. automodule:: otcextensions.sdk.vlb.v3.availability_zone

The AvailabilityZone Class
--------------------------

The ``AvailabilityZone`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.vlb.v3.availability_zone.AvailabilityZone
   :members:
